<?php
namespace Modules\Properties;
use Modules\Core\Helpers\SitemapHelper;
use Modules\ModuleServiceProvider;
use Modules\Properties\Models\Properties;
use Modules\User\Helpers\PermissionHelper;

class ModuleProvider extends ModuleServiceProvider
{


    public function boot(SitemapHelper $sitemapHelper){

        $this->loadMigrationsFrom(__DIR__ . '/Migrations');

        if(is_installed() and Properties::isEnable()){
            $sitemapHelper->add("properties",[app()->make(Properties::class),'getForSitemap']);
        }

        PermissionHelper::add([
            // Properties
            'properties_view',
            'properties_create',
            'properties_update',
            'properties_delete',
            'properties_manage_others',
            'properties_manage_attributes',
        ]);
    }
    /**
     * Register bindings in the container.
     *
     * @return void
     */
    public function register()
    {
        $this->app->register(RouterServiceProvider::class);
    }

    public static function getAdminMenu()
    {
        if(!Properties::isEnable()) return [];
        return [
            'properties'=>[
                "position"=> 41,
                'url'        => route('properties.admin.index'),
                'title'      => __('Properties'),
                'icon'       => 'ion ion-md-home',
                'permission' => 'properties_view',
                'children'   => [
                    'add'=>[
                        'url'        => route('properties.admin.index'),
                        'title'      => __('All Properties'),
                        'permission' => 'properties_view',
                    ],
                    'create'=>[
                        'url'        => route('properties.admin.create'),
                        'title'      => __('Add new Properties'),
                        'permission' => 'properties_create',
                    ],
                    'attribute'=>[
                        'url'        => route('properties.admin.attribute.index'),
                        'title'      => __('Attributes'),
                        'permission' => 'properties_manage_attributes',
                    ],
                    'availability'=>[
                        'url'        => route('properties.admin.availability.index'),
                        'title'      => __('Availability'),
                        'permission' => 'properties_create',
                    ],
                    'recovery'=>[
                        'url'        => route('properties.admin.recovery'),
                        'title'      => __('Recovery'),
                        'permission' => 'properties_view',
                    ],

                ]
            ]
        ];
    }

    public static function getBookableServices()
    {
        if(!Properties::isEnable()) return [];
        return [
            'properties'=>Properties::class
        ];
    }

    public static function getMenuBuilderTypes()
    {
        if(!Properties::isEnable()) return [];
        return [
            'properties'=>[
                'class' => Properties::class,
                'name'  => __("Properties"),
                'items' => Properties::searchForMenu(),
                'position'=>41
            ]
        ];
    }

    public static function getUserMenu()
    {
        $res = [];
        if (Properties::isEnable()) {
            $res['properties'] = [
                'url'        => route('properties.vendor.index'),
                'title'      => __("Manage Properties"),
                'icon'       => Properties::getServiceIconFeatured(),
                'position'   => 50,
                'permission' => 'properties_view',
                'children'   => [
                    [
                        'url'   => route('properties.vendor.index'),
                        'title' => __("All Properties"),
                    ],
                    [
                        'url'        => route('properties.vendor.create'),
                        'title'      => __("Add Properties"),
                        'permission' => 'properties_create',
                    ],
                    [
                        'url'        => route('properties.vendor.availability.index'),
                        'title'      => __("Availability"),
                        'permission' => 'properties_create',
                    ],
                    [
                        'url'   => route('properties.vendor.recovery'),
                        'title'      => __("Recovery"),
                        'permission' => 'properties_create',
                    ],
                ]
            ];
        }
        return $res;
    }

    public static function getTemplateBlocks(){
        if(!Properties::isEnable()) return [];
        return [
            'form_search_properties'=>"\\Modules\\Properties\\Blocks\\FormSearchProperties",
            'list_properties'=>"\\Modules\\Properties\\Blocks\\ListProperties",
            'properties_term_featured_box'=>"\\Modules\\Properties\\Blocks\\PropertiesTermFeaturedBox",
        ];
    }
}
