<?php
namespace Modules\Report\Admin;

use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Modules\AdminController;
use Modules\Booking\Emails\NewBookingEmail;
use Modules\Booking\Events\BookingUpdatedEvent;
use Modules\Booking\Models\Booking;
use DB;

class BookingController extends AdminController
{
    public function __construct()
    {
        $this->setActiveMenu(route('report.admin.booking'));
    }

    public function index(Request $request)
    {
        $this->checkPermission('booking_view');
        $query = Booking::where('status', '!=', 'draft');
        if (!empty($request->s)) {
            if( is_numeric($request->s) ){
                $query->Where('id', '=', $request->s);
            }else{
                $query->where(function ($query) use ($request) {
                    $query->where('first_name', 'like', '%' . $request->s . '%')
                        ->orWhere('last_name', 'like', '%' . $request->s . '%')
                        ->orWhere('email', 'like', '%' . $request->s . '%')
                        ->orWhere('phone', 'like', '%' . $request->s . '%')
                        ->orWhere('address', 'like', '%' . $request->s . '%')
                        ->orWhere('address2', 'like', '%' . $request->s . '%');
                });
            }
        }
        if ($this->hasPermission('booking_manage_others')) {
            if (!empty($request->vendor_id)) {
                $query->where('vendor_id', $request->vendor_id);
            }
        } else {
            $query->where('vendor_id', Auth::id());
        }
        $query->whereIn('object_model', array_keys(get_bookable_services()));
        $query->orderBy('id','desc');

     
        $data = [
            'rows'                  => $query->paginate(20),
            'page_title'            => __("All Bookings"),
            'booking_manage_others' => $this->hasPermission('booking_manage_others'),
            'booking_update'        => $this->hasPermission('booking_update'),
            'statues'               => config('booking.statuses')
        ];
        return view('Report::admin.booking.index', $data);
    }

    public function bulkEdit(Request $request)
    {
        $ids = $request->input('ids');
        $action = $request->input('action');
        if (empty($ids) or !is_array($ids)) {
            return redirect()->back()->with('error', __('No items selected'));
        }
        if (empty($action)) {
            return redirect()->back()->with('error', __('Please select action'));
        }
        if ($action == "delete") {
            foreach ($ids as $id) {
                $query = Booking::where("id", $id);
                if (!$this->hasPermission('booking_manage_others')) {
                    $query->where("vendor_id", Auth::id());
                }
                $row = $query->first();
                if(!empty($row)){
                    $row->delete();
                    event(new BookingUpdatedEvent($row));

                }
            }
        } else {
            foreach ($ids as $id) {
                $query = Booking::where("id", $id);
                if (!$this->hasPermission('booking_manage_others')) {
                    $query->where("vendor_id", Auth::id());
                    $this->checkPermission('booking_update');
                }
                $item = $query->first();
                if(!empty($item)){
                    $item->status = $action;
                    $item->save();

                    if($action == Booking::CANCELLED) $item->tryRefundToWallet();
                    event(new BookingUpdatedEvent($item));
                }
            }
        }
        return redirect()->back()->with('success', __('Update success'));
    }

    public function email_preview(Request $request, $id)
    {
        $booking = Booking::find($id);
        return (new NewBookingEmail($booking))->render();
    }
     
     public function pay(Request $request)
    {   

          $user_balance=0;

         $booking = Booking::find($request->booking_id);

         if($booking->object_model=='hotel'){

            $tablename="bravo_hotels";

         } else if($booking->object_model=='tour'){

              $tablename="bravo_tours";       

         } else if($booking->object_model=='car'){

              $tablename="bravo_cars";       

         } else if($booking->object_model=='spaces'){

              $tablename="bravo_spaces";       

         } else if($booking->object_model=='properties'){

              $tablename="bravo_properties";       

         }

          $bookingprice=$booking->paid;

          $bookingdate=explode(" ",$booking->start_date);

          $checkindate=$bookingdate[0];
         //$checkindate='2023-01-24';
         $now=date('Y-m-d');

         $bookingcommission=$booking->commission;

         $postsingle  = DB::table($tablename)->where('id', $booking->object_id)->first();

         if($postsingle->cancellation=='Flexible'){
               $canceltype='flexible';
               $numberofdays=setting_item('flexible_day_before');
               $daybforecancel="-".setting_item('flexible_day_before')."day";
               $daybeforpercent=setting_item('flexible_day_before_percentage');
               $dayafterpercent=setting_item('flexible_day_after_percentage');

               $checkbeforeday=date('Y-m-d', strtotime($checkindate . $daybforecancel));             
                }

            else if($postsingle->cancellation=='Moderate'){
               $canceltype='moderate';
               $numberofdays=setting_item('moderate_day_before');
               $daybforecancel="-".setting_item('moderate_day_before')."day";
               $daybeforpercent=setting_item('moderate_day_before_percentage');
               $dayafterpercent=setting_item('moderate_day_after_percentage');
               $checkbeforeday=date('Y-m-d', strtotime($checkindate . $daybforecancel));

                }

             else if($postsingle->cancellation=='Strict'){
               $canceltype='strict';
               $numberofdays=setting_item('strict_day_before');
               $daybforecancel="-".setting_item('strict_day_before')."day";
               $daybeforpercent=setting_item('strict_day_before_percentage');
               $dayafterpercent=setting_item('strict_day_after_percentage');
               $checkbeforeday=date('Y-m-d', strtotime($checkindate . $daybforecancel));

                } 
                
                
                 $datetime1 = strtotime($checkindate); // convert to timestamps
                 $datetime2 = strtotime($now); // convert to timestamps
                 $days = (int)(($datetime2 - $datetime1)/86400); // will give the difference in days , 86400 is the timestamp difference of a day
                     
                    $checkdays=str_replace("-","",$days);


                  if($checkdays >=$numberofdays){

                    $percentage = $daybeforpercent;

                  } else if($checkdays <=$numberofdays){

                        if($dayafterpercent==''){
                         $dayafterpercent=0;
                       }
                      $percentage = $dayafterpercent;
                    
                  } 


                   $amt = $booking->total_before_fees - $bookingcommission;
                                        
                  //$orderamtaftercomm= ( $bookingprice * ( ( 100 - $bookingcommission ) / 100 ) );

                  $refundamt=($percentage / 100) * $amt;

                  $wallet     = DB::table('user_wallets')->where('holder_id', $booking->vendor_id)->first();

                              if($refundamt==0){
                        $partnertot=$wallet->balance;
                         } else {
                         $partnertot=$wallet->balance - $bookingprice;    
                       }
                          
                          //host wallet
                       $hostbalance      = $wallet->balance - $refundamt;


                         DB::table('user_wallets')->where(['holder_id' => $booking->vendor_id])->update(['balance' => $hostbalance]);


                       //customer wallet

                    $customerwallet     = DB::table('user_wallets')->where('holder_id', $request->customer_id)->first();  
                    
                     $custmerbalance =  $customerwallet->balance + $refundamt;

                      DB::table('user_wallets')->where(['holder_id' => $request->customer_id])->update(['balance' => $custmerbalance]);
                          

                    Booking::where(['id' => $request->booking_id])->update(['refund_status' => 'Yes', 'vendor_refund_amt' => $refundamt ]);
        
        /* host wallet */
          /*$host_balance=0;
          $walletBalance_vendorcnt  = DB::table('user_wallets')->where('holder_id', $request->vendor_id)->count();
        
         $walletBalance_vendor  = DB::table('user_wallets')->where('holder_id', $request->vendor_id)->first();
           
           if($walletBalance_vendorcnt > 0){

          if($walletBalance_vendor->balance!=''){

           $host_balance=$walletBalance_vendor->balance;

          } 

           }

        $balance2              = ( $host_balance + $request->vendor_refund_amt );
        
        DB::table('user_wallets')->where(['holder_id' => $request->vendor_id])->update(['balance' => $balance2]); */
         
        return redirect()->back()->with('success', __('Update success'));
    }


}
